2022-07-15 Version: 1.1.20
- Add open file detect api.

2022-07-14 Version: 1.1.19
- Add open file detect api.

2022-07-08 Version: 1.1.18
- Add open file detect api.

2022-07-04 Version: 1.1.17
- Add open file detect api.

2022-06-23 Version: 1.1.16
- Add open file detect api.

2022-06-20 Version: 1.1.15
- Add EventId when listQuery EventInfo.

2022-05-27 Version: 1.1.14
- Generated python 2018-12-03 for Sas.

2022-05-18 Version: 1.1.13
- Generated python 2018-12-03 for Sas.

2022-05-12 Version: 1.1.12
- Generated python 2018-12-03 for Sas.

2022-05-10 Version: 1.1.11
- Generated python 2018-12-03 for Sas.

2022-04-21 Version: 1.1.10
- Generated python 2018-12-03 for Sas.

2022-04-20 Version: 1.1.9
- Generated python 2018-12-03 for Sas.

2022-04-19 Version: 1.1.8
- Generated python 2018-12-03 for Sas.

2022-04-13 Version: 1.1.7
- Generated python 2018-12-03 for Sas.

2022-04-11 Version: 1.1.6
- Generated python 2018-12-03 for Sas.

2022-04-07 Version: 1.1.5
- Generated python 2018-12-03 for Sas.

2022-04-01 Version: 1.1.4
- Generated python 2018-12-03 for Sas.

2022-03-31 Version: 1.1.3
- Generated python 2018-12-03 for Sas.

2022-03-25 Version: 1.1.2
- Generated python 2018-12-03 for Sas.

2022-03-21 Version: 1.1.1
- Generated python 2018-12-03 for Sas.

2022-03-14 Version: 1.1.0
- Generated python 2018-12-03 for Sas.

2022-02-28 Version: 1.0.15
- Support DescribeSuspEvents, DescribeAlarmEventList API.

2022-02-25 Version: 1.0.14
- Generated python 2018-12-03 for Sas.

2022-02-21 Version: 1.0.13
- Support DescribeImageListWithBaselineName API.

2022-02-09 Version: 1.0.12
- AMP Version Change.

2021-12-27 Version: 1.0.11
- Support DescribeAccessKeyLeakDetail API.

2021-11-12 Version: 1.0.10
- Support ExportVul API.

2021-11-02 Version: 1.0.9
- Support DescribeInstallCodes API.

2021-09-17 Version: 1.0.8
- Support DescribeVulExportInfo API.

2021-09-15 Version: 1.0.7
- Support DescribeWarningMachines API.

2021-08-18 Version: 1.0.6
- Support RefreshAssets API.

2021-06-25 Version: 1.0.5
- Support DescribeSuspEventDetail API.

2021-06-18 Version: 1.0.4
- Generated python 2018-12-03 for Sas.

2021-05-17 Version: 1.0.3
- Generated python 2018-12-03 for Sas.

2021-05-17 Version: 1.0.2
- Generated python 2018-12-03 for Sas.

2021-05-14 Version: 1.0.1
- Generated python 2018-12-03 for Sas.

2020-12-30 Version: 1.0.0
- AMP Version Change.

